==> history-issue-common-1.0.0-20220908.055630-9-sources.jar: cn/gtmap/realestate/supervise/entity/CqazRwxx.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 拆迁安置任务信息表实体类
 *
 * @author huming
 * @since 2022-08-22
 */
@Table(name = "CQAZ_RWXX")
public class CqazRwxx implements Serializable {
    private static final long serialVersionUID = -86991230293858200L;
    /**
     * 主键ID
     */
    @Id
    private String id;
    /**
     * 区划代码
     */
    private Object qhdm;
    /**
     * 区划名称
     */
    private String qhmc;
    /**
     * 项目名称
     */
    private String xmmc;
    /**
     * 化解责任人名称
     */
    private String hjzrrmc;
    /**
     * 化解责任人电话
     */
    private String hjzrrdh;
    /**
     * 楼号
     */
    private String lh;
    /**
     * 单元号
     */
    private String dyh;
    /**
     * 户号
     */
    private String hh;
    /**
     * 实际建成时间
     */
    private String sjjcsj;
    /**
     * 预计完成时间
     */
    private String yjwcsj1;

    /**
     * 预计完成时间
     * 3个月集中整改期内完成
     */
    private String yjwcsj2;
    /**
     * 实际完成时间
     * 1年内完成
     */
    private String sjwcsj;
    /**
     * 解决方法
     */
    private String jjff;
    /**
     * 土地性质
     */
    private String tdxz;
    /**
     * 其他问题说明
     */
    private Object qtwtsm;
    /**
     * 化解状态(0：未化解,1：已化解)
     */
    private Object hjzt;
    /**
     * 化解时间
     */
    private Date hjsj;
    /**
     * 创建时间
     */
    private Date cjsj;
    /**
     * 数据更新时间
     */
    private Date sjgxsj;

    private String col0;

    private String col1;

    private String col2;

    private String col3;

    private String col4;

    private String col5;

    private String col6;

    private String col7;

    private String col8;

    private String col9;

    private String col10;

    private String col11;

    private String sfzzjs;

    //不动产单元号
    private String bdcdyh;

    //不动产单元号
    private String bdcqzh;

    //不动产单元号
    private String sfblscdj;

    //不动产单元号
    private String sfblzydj;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getSfblscdj() {
        return sfblscdj;
    }

    public void setSfblscdj(String sfblscdj) {
        this.sfblscdj = sfblscdj;
    }

    public String getSfblzydj() {
        return sfblzydj;
    }

    public void setSfblzydj(String sfblzydj) {
        this.sfblzydj = sfblzydj;
    }

    public String getSfzzjs() {
        return sfzzjs;
    }

    public void setSfzzjs(String sfzzjs) {
        this.sfzzjs = sfzzjs;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Object getQhdm() {
        return qhdm;
    }

    public void setQhdm(Object qhdm) {
        this.qhdm = qhdm;
    }

    public String getQhmc() {
        return qhmc;
    }

    public void setQhmc(String qhmc) {
        this.qhmc = qhmc;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getHjzrrmc() {
        return hjzrrmc;
    }

    public void setHjzrrmc(String hjzrrmc) {
        this.hjzrrmc = hjzrrmc;
    }

    public String getHjzrrdh() {
        return hjzrrdh;
    }

    public void setHjzrrdh(String hjzrrdh) {
        this.hjzrrdh = hjzrrdh;
    }

    public String getLh() {
        return lh;
    }

    public void setLh(String lh) {
        this.lh = lh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public String getHh() {
        return hh;
    }

    public void setHh(String hh) {
        this.hh = hh;
    }

    public Object getQtwtsm() {
        return qtwtsm;
    }

    public void setQtwtsm(Object qtwtsm) {
        this.qtwtsm = qtwtsm;
    }

    public Object getHjzt() {
        return hjzt;
    }

    public void setHjzt(Object hjzt) {
        this.hjzt = hjzt;
    }

    public Date getHjsj() {
        return hjsj;
    }

    public void setHjsj(Date hjsj) {
        this.hjsj = hjsj;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getSjjcsj() {
        return sjjcsj;
    }

    public void setSjjcsj(String sjjcsj) {
        this.sjjcsj = sjjcsj;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getCol1() {
        return col1;
    }

    public void setCol1(String col1) {
        this.col1 = col1;
    }

    public String getCol2() {
        return col2;
    }

    public void setCol2(String col2) {
        this.col2 = col2;
    }

    public String getCol3() {
        return col3;
    }

    public void setCol3(String col3) {
        this.col3 = col3;
    }

    public String getCol4() {
        return col4;
    }

    public void setCol4(String col4) {
        this.col4 = col4;
    }

    public String getCol5() {
        return col5;
    }

    public void setCol5(String col5) {
        this.col5 = col5;
    }

    public String getCol6() {
        return col6;
    }

    public void setCol6(String col6) {
        this.col6 = col6;
    }

    public String getCol7() {
        return col7;
    }

    public void setCol7(String col7) {
        this.col7 = col7;
    }

    public String getCol8() {
        return col8;
    }

    public void setCol8(String col8) {
        this.col8 = col8;
    }

    public String getYjwcsj1() {
        return yjwcsj1;
    }

    public void setYjwcsj1(String yjwcsj1) {
        this.yjwcsj1 = yjwcsj1;
    }

    public String getYjwcsj2() {
        return yjwcsj2;
    }

    public void setYjwcsj2(String yjwcsj2) {
        this.yjwcsj2 = yjwcsj2;
    }

    public String getSjwcsj() {
        return sjwcsj;
    }

    public void setSjwcsj(String sjwcsj) {
        this.sjwcsj = sjwcsj;
    }

    public String getJjff() {
        return jjff;
    }

    public void setJjff(String jjff) {
        this.jjff = jjff;
    }

    public String getTdxz() {
        return tdxz;
    }

    public void setTdxz(String tdxz) {
        this.tdxz = tdxz;
    }

    public String getCol9() {
        return col9;
    }

    public void setCol9(String col9) {
        this.col9 = col9;
    }

    public String getCol0() {
        return col0;
    }

    public void setCol0(String col0) {
        this.col0 = col0;
    }

    public String getCol10() {
        return col10;
    }

    public void setCol10(String col10) {
        this.col10 = col10;
    }

    public String getCol11() {
        return col11;
    }

    public void setCol11(String col11) {
        this.col11 = col11;
    }
}

==> history-issue-common-1.0.0-20231221.110741-11-sources.jar: cn/gtmap/realestate/supervise/entity/CqazRwxx.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 拆迁安置任务信息表实体类
 *
 * @author huming
 * @since 2022-08-22
 */
@Table(name = "CQAZ_RWXX")
public class CqazRwxx implements Serializable {
    private static final long serialVersionUID = -86991230293858200L;
    /**
     * 主键ID
     */
    @Id
    private String id;
    /**
     * 区划代码
     */
    private String qhdm;
    /**
     * 区划名称
     */
    private String qhmc;
    /**
     * 项目名称
     */
    private String xmmc;
    /**
     * 化解责任人名称
     */
    private String hjzrrmc;
    /**
     * 化解责任人电话
     */
    private String hjzrrdh;
    /**
     * 楼号
     */
    private String lh;
    /**
     * 单元号
     */
    private String dyh;
    /**
     * 户号
     */
    private String hh;
    /**
     * 实际建成时间
     */
    private String sjjcsj;
    /**
     * 预计完成时间
     */
    private String yjwcsj1;

    /**
     * 预计完成时间
     * 3个月集中整改期内完成
     */
    private String yjwcsj2;
    /**
     * 实际完成时间
     * 1年内完成
     */
    private String sjwcsj;
    /**
     * 解决方法
     */
    private String jjff;
    /**
     * 土地性质
     */
    private String tdxz;
    /**
     * 其他问题说明
     */
    private Object qtwtsm;
    /**
     * 化解状态(0：未化解,1：已化解)
     */
    private Object hjzt;
    /**
     * 化解时间
     */
    private Date hjsj;
    /**
     * 创建时间
     */
    private Date cjsj;
    /**
     * 数据更新时间
     */
    private Date sjgxsj;

    private String col0;

    private String col1;

    private String col2;

    private String col3;

    private String col4;

    private String col5;

    private String col6;

    private String col7;

    private String col8;

    private String col9;

    private String col10;

    private String col11;

    private String sfzzjs;

    //不动产单元号
    private String bdcdyh;

    //首次登记产权登记
    private String bdcqzh;

    //转移登记产权登记
    private String zybdcqzh;

    private String sfblscdj;

    private String sfblzydj;

    private String hsscdj;

    private String hszydj;

    private String fjmc;

    private String fjdz;

    private String fazf;

    public String getFazf() {
        return fazf;
    }

    public void setFazf(String fazf) {
        this.fazf = fazf;
    }

    public String getZybdcqzh() {
        return zybdcqzh;
    }

    public void setZybdcqzh(String zybdcqzh) {
        this.zybdcqzh = zybdcqzh;
    }

    public String getFjmc() {
        return fjmc;
    }

    public void setFjmc(String fjmc) {
        this.fjmc = fjmc;
    }

    public String getFjdz() {
        return fjdz;
    }

    public void setFjdz(String fjdz) {
        this.fjdz = fjdz;
    }

    public String getHsscdj() {
        return hsscdj;
    }

    public void setHsscdj(String hsscdj) {
        this.hsscdj = hsscdj;
    }

    public String getHszydj() {
        return hszydj;
    }

    public void setHszydj(String hszydj) {
        this.hszydj = hszydj;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getSfblscdj() {
        return sfblscdj;
    }

    public void setSfblscdj(String sfblscdj) {
        this.sfblscdj = sfblscdj;
    }

    public String getSfblzydj() {
        return sfblzydj;
    }

    public void setSfblzydj(String sfblzydj) {
        this.sfblzydj = sfblzydj;
    }

    public String getSfzzjs() {
        return sfzzjs;
    }

    public void setSfzzjs(String sfzzjs) {
        this.sfzzjs = sfzzjs;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getQhdm() {
        return qhdm;
    }

    public void setQhdm(String qhdm) {
        this.qhdm = qhdm;
    }

    public String getQhmc() {
        return qhmc;
    }

    public void setQhmc(String qhmc) {
        this.qhmc = qhmc;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getHjzrrmc() {
        return hjzrrmc;
    }

    public void setHjzrrmc(String hjzrrmc) {
        this.hjzrrmc = hjzrrmc;
    }

    public String getHjzrrdh() {
        return hjzrrdh;
    }

    public void setHjzrrdh(String hjzrrdh) {
        this.hjzrrdh = hjzrrdh;
    }

    public String getLh() {
        return lh;
    }

    public void setLh(String lh) {
        this.lh = lh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public String getHh() {
        return hh;
    }

    public void setHh(String hh) {
        this.hh = hh;
    }

    public Object getQtwtsm() {
        return qtwtsm;
    }

    public void setQtwtsm(Object qtwtsm) {
        this.qtwtsm = qtwtsm;
    }

    public Object getHjzt() {
        return hjzt;
    }

    public void setHjzt(Object hjzt) {
        this.hjzt = hjzt;
    }

    public Date getHjsj() {
        return hjsj;
    }

    public void setHjsj(Date hjsj) {
        this.hjsj = hjsj;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getSjjcsj() {
        return sjjcsj;
    }

    public void setSjjcsj(String sjjcsj) {
        this.sjjcsj = sjjcsj;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getCol1() {
        return col1;
    }

    public void setCol1(String col1) {
        this.col1 = col1;
    }

    public String getCol2() {
        return col2;
    }

    public void setCol2(String col2) {
        this.col2 = col2;
    }

    public String getCol3() {
        return col3;
    }

    public void setCol3(String col3) {
        this.col3 = col3;
    }

    public String getCol4() {
        return col4;
    }

    public void setCol4(String col4) {
        this.col4 = col4;
    }

    public String getCol5() {
        return col5;
    }

    public void setCol5(String col5) {
        this.col5 = col5;
    }

    public String getCol6() {
        return col6;
    }

    public void setCol6(String col6) {
        this.col6 = col6;
    }

    public String getCol7() {
        return col7;
    }

    public void setCol7(String col7) {
        this.col7 = col7;
    }

    public String getCol8() {
        return col8;
    }

    public void setCol8(String col8) {
        this.col8 = col8;
    }

    public String getYjwcsj1() {
        return yjwcsj1;
    }

    public void setYjwcsj1(String yjwcsj1) {
        this.yjwcsj1 = yjwcsj1;
    }

    public String getYjwcsj2() {
        return yjwcsj2;
    }

    public void setYjwcsj2(String yjwcsj2) {
        this.yjwcsj2 = yjwcsj2;
    }

    public String getSjwcsj() {
        return sjwcsj;
    }

    public void setSjwcsj(String sjwcsj) {
        this.sjwcsj = sjwcsj;
    }

    public String getJjff() {
        return jjff;
    }

    public void setJjff(String jjff) {
        this.jjff = jjff;
    }

    public String getTdxz() {
        return tdxz;
    }

    public void setTdxz(String tdxz) {
        this.tdxz = tdxz;
    }

    public String getCol9() {
        return col9;
    }

    public void setCol9(String col9) {
        this.col9 = col9;
    }

    public String getCol0() {
        return col0;
    }

    public void setCol0(String col0) {
        this.col0 = col0;
    }

    public String getCol10() {
        return col10;
    }

    public void setCol10(String col10) {
        this.col10 = col10;
    }

    public String getCol11() {
        return col11;
    }

    public void setCol11(String col11) {
        this.col11 = col11;
    }
}
